==> rsudp-2.0.1.tar.gz: rsudp-2.0.1/setup.py <==
import setuptools
from rsudp import _version

with open("README.md", "r") as fh:
    long_description = fh.read()


setuptools.setup(
    name="rsudp",
    version=_version.version,
    author="Ian Nesbitt",
    author_email="ian.nesbitt@raspberryshake.org",
    license='GPLv3',
    description="Tools for receiving and interacting with Raspberry Shake UDP data",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/raspishake/rsudp",
    packages=setuptools.find_packages(),
    include_package_data=True,
    install_requires=['obspy',
                      'numpy>=2.0.0,<3',
                      'matplotlib>3.2,<4',
                      'pydub',
                      'twython',
                      'python-telegram-bot'],
    entry_points = {
        'console_scripts': [
            'rs-packetloss=rsudp.packetloss:main',
            'rs-client=rsudp.client:main',
            'rs-test=rsudp.client:test',
            'packetize=rsudp.packetize:main',
            'rs-settings=rsudp.entry_points:ep_edit_settings',
            'rs-log=rsudp.entry_points:ep_cat_log',
            'rs-tailf=rsudp.entry_points:ep_tailf_log',
            ],
    },
    classifiers=[
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
        "Operating System :: OS Independent",
        "Framework :: Matplotlib",
        "Topic :: Scientific/Engineering :: Physics",
        "Intended Audience :: Education",
        "Intended Audience :: End Users/Desktop",
        "Intended Audience :: Science/Research",
        "Intended Audience :: Developers",
        "Natural Language :: English",
        "Development Status :: 5 - Production/Stable",
    ],
)

==> rsudp-2.2.0.tar.gz: rsudp-2.2.0/setup.py <==
import setuptools
from rsudp import _version

with open("README.md", "r") as fh:
    long_description = fh.read()


setuptools.setup(
    name="rsudp",
    version=_version.version,
    author="Ian Nesbitt",
    author_email="ian.nesbitt@raspberryshake.org",
    license='GPLv3',
    description="Tools for receiving and interacting with Raspberry Shake UDP data",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/raspishake/rsudp",
    packages=setuptools.find_packages(),
    include_package_data=True,
    install_requires=['obspy',
                      'numpy>=2.0.0,<3',
                      'matplotlib>3.2,<4',
                      'pydub',
                      'twython',
                      'python-telegram-bot>=20,<21'],
    entry_points = {
        'console_scripts': [
            'rs-packetloss=rsudp.packetloss:main',
            'rs-client=rsudp.client:main',
            'rs-test=rsudp.client:test',
            'packetize=rsudp.packetize:main',
            'rs-settings=rsudp.entry_points:ep_edit_settings',
            'rs-log=rsudp.entry_points:ep_cat_log',
            'rs-tailf=rsudp.entry_points:ep_tailf_log',
            ],
    },
    classifiers=[
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
        "Operating System :: OS Independent",
        "Framework :: Matplotlib",
        "Topic :: Scientific/Engineering :: Physics",
        "Intended Audience :: Education",
        "Intended Audience :: End Users/Desktop",
        "Intended Audience :: Science/Research",
        "Intended Audience :: Developers",
        "Natural Language :: English",
        "Development Status :: 5 - Production/Stable",
    ],
)
